@@ -43,7 +43,7 @@ class Thing:
                 Scene()  # Scene add itself to the World
 
             """ Use the default  Scene """
-            self._scene = World.scenes[0]
+            self._scene = World.first_scene()
 
         # Add then thing built to the scene
         if parent is None:
@@ -137,3 +137,8 @@ class Thing:
             decorator.decorate(self)
             for child in self._children:
                 decorator.decorate(child)
+
+    def find_bounding_box(self):
+        """ Compute the bounding box of the Thing """
+
+        return self.position, self.end_position
